@@ -1,3 +1,4 @@
+
 module Compiler where
 import ImperativeState
 import MyState
@@ -18,24 +19,32 @@ import Codec.Binary.UTF8.String
 import Control.Monad.State
 import UrlAnalyse
 import Data.ByteString.UTF8 (toString)
-import Data.ByteString hiding (take,reverse,dropWhile,takeWhile,drop,map,concat,elem,length,zip,head,filter,minimum,isInfixOf)
-
-
-compile::RunMode->String->String->[[ByteString]]->ImperativeMonad CompileResult
-compile theRunMode text templates tabs= 
-                                do st<-get
-                                   case theRunMode of 
-                                    StandardTemplates -> return (run2 (parseit parsers text) (hostname .fullUrl $st) templates tabs)
-                                    UserTemplateFile _ -> return (run2 (parseit parsers text) (hostname .fullUrl $st) templates tabs)
-                                    HTML -> return (run2 (printPrepareTree (parseit minparsers text)) (hostname .fullUrl $st) templates tabs)
-
-                                    ExpandedTemplates -> return (run2 (parseit parsers text) (hostname .fullUrl $st) templates tabs)
-
-
-
-
-
-
+import Data.ByteString
+       hiding (take, reverse, dropWhile, takeWhile, drop, map, concat,
+               elem, length, zip, head, filter, minimum, isInfixOf)
+ 
+compile ::
+        RunMode ->
+          String -> String -> [[ByteString]] -> ImperativeMonad CompileResult
+compile theRunMode text templates tabs
+  = do st <- get
+       --liftIO $ print (printPrepareTree(parseit minparsers text))
+       case theRunMode of
+           StandardTemplates -> return
+                                  (run2 (parseit parsers text) (hostname . fullUrl $ st) templates
+                                     tabs)
+           UserTemplateFile _ -> return
+                                   (run2 (parseit parsers text) (hostname . fullUrl $ st) templates
+                                      tabs)
+           HTML -> return
+                     (run2 (printPrepareTree (parseit minparsers text))
+                        (hostname . fullUrl $ st)
+                        templates
+                        tabs)
+           ExpandedTemplates -> return
+                                  (run2 (parseit parsers text) (hostname . fullUrl $ st) templates
+                                     tabs)
+ 
 {-DHUN| pathname of the temporary directory of the compiler |DHUN-}
  
 dirpref :: [Char]
@@ -109,7 +118,9 @@ printPrepareTree ll = concat (map printPrepareNode ll)
         printPrepareNode (Environment Wikitable (TagAttr "table" m) _)
           | (Map.lookup "class" m) == (Just "toc") = []
         printPrepareNode (Environment Tag (TagAttr "div" m) _)
-          | ((Map.lookup "class" m) == (Just "toc") || (Map.lookup "id" m) == (Just "toc")) = []
+          | ((Map.lookup "class" m) == (Just "toc") ||
+               (Map.lookup "id" m) == (Just "toc"))
+            = []
         printPrepareNode (Environment Wikitable (TagAttr "table" m) _)
           | (Map.lookup "class" m) == (Just "navbox") = []
         printPrepareNode (Environment Tag (TagAttr "title" _) _) = []
@@ -148,6 +159,12 @@ printPrepareTree ll = concat (map printPrepareNode ll)
               of
                 Just x -> x
                 _ -> printPrepareTree l
+        printPrepareNode (Environment TableHeadColSep (TagAttr t m) l)
+          = [Environment TableHeadColSep (TagAttr t m) (l++ (map (\x->Environment Attribute (Attr x) []) (Map.toList m)))]
+        printPrepareNode (Environment TableColSep (TagAttr t m) l)
+          = [Environment TableColSep (TagAttr t m) (l++ (map (\x->Environment Attribute (Attr x) []) (Map.toList m)))]
+        printPrepareNode (Environment TableRowSep (TagAttr t m) l)
+          = [Environment TableRowSep (TagAttr t m) (l++ (map (\x->Environment Attribute (Attr x) []) (Map.toList m)))]
         printPrepareNode (Environment Tag (TagAttr "pre" m) l)
           = [Environment Preformat (TagAttr "pre" m) l]
         printPrepareNode (Environment Tag (TagAttr "span" m) _)
@@ -205,7 +222,8 @@ printPrepareTree ll = concat (map printPrepareNode ll)
               if isUTF8Encoded z then decodeString z else z
         imgfun m l tt
           = maybeToList $
-              do t <- case (fmap (parseit imgparsers) (Map.lookup "title" m)) `mplus` tt of
+              do t <- case
+                        (fmap (parseit imgparsers) (Map.lookup "title" m)) `mplus` tt of
                           Just x -> return $ [C '|'] ++ x
                           Nothing -> return []
                  h <- case filter (mypred "img") l of
@@ -266,7 +284,6 @@ printparse x
   = do Tools.writeFile (dirpref ++ "done") ""
        return (printPrepareTree (parseit minparsers x))
  
- 
 {-DHUN| converts a wiki source document to a parse tree to be converted to LaTeX be treeToLaTeX3. The first parameter is that list of parsers. That is the list of environments to be recognized by the parser. This is usually either only plain HTML, or HTML mixed with mediawiki markup. The second parameter is the source code to be parsed. This function returns a parse tree |DHUN-}
  
 parseit :: [MyParser Char] -> String -> [Anything Char]
@@ -321,53 +338,52 @@ postproctabmap m = Map.map f m
               (Map.mapKeys (\ k -> k - 1)
                  (Map.map (\ x -> (x + 12.333748 - (minimum (Map.elems m1)))) m1))
  
-
-
-
-
-data CompileResult = CompileResult {images::[String],body::String,tablelist::[[String]],galleryNumbers::[Integer],title::String}
-
+data CompileResult = CompileResult{images :: [String],
+                                   body :: String, tablelist :: [[String]],
+                                   galleryNumbers :: [Integer], title :: String}
+ 
 {-DHUN| the first parameter is the parse tree created by get parse of the document currently being processed. the second parameter is the URL under which the document was downloaded. the third parameter is the netloc describing the wiki this page belongs to. The fourth parameter is a mapping file defined by the user for the mapping of mediawiki templates to latex commands. the fifth parameter is a possible parse tree created by precious run the the should be added before the begging of the newly created parse tree. This function writes out all results to temporary files that will be further processed by compiler.py DHUN-}
  
 run2 ::
-    [Anything Char] ->
-      String -> String ->[[ByteString]]-> CompileResult
+     [Anything Char] ->
+       String -> String -> [[ByteString]] -> CompileResult
 run2 parsetree netloc tmpl someTables
-  = CompileResult {images=img,body=bdy,tablelist=theTables,galleryNumbers=gals,title=tit}
-  where 
-    alldata2 g u
+  = CompileResult{images = img, body = bdy, tablelist = theTables,
+                  galleryNumbers = gals, title = tit}
+  where alldata2 g u
           = (treeToLaTeX3 ((snd . newtree $ g))
                initialState{urld = analyseNetloc netloc}{tabmap = u,
-                                                    templateMap =
-                                                      getUserTemplateMap
-                                                        (read tmpl :: [[String]])}{urls =
-                                                                                     mUrlState .
-                                                                                       fst . newtree
-                                                                                       $ g})
-    newtree g = makeLables g initialUrlState
-    tm=(postproctabmap (maketabmap theNewSizes Map.empty)) 
-    (trda, trst)= (alldata2 parsetree tm)
-    img= (map (\ g -> ((replace '\n' ' ' g) ))
-               (getImages trst))
-    theTables= reverse (tablist trst)
-    bdy= doUnicode trda
-    gals= getGalleryNumbers trst
-    tit= getTitle trst
-    fun::ByteString->Double
-    fun x = case reads (toString x) of 
-              [(f,_)]-> f
-              _ -> (1000.0)
-    theSizes= zip [1..] (map (\x->zip [1..] (map fun x)) someTables) 
-    theNewSizes = concat (map sizeFun theSizes)
-    sizeFun (t,k)= map (\(s,b)-> ([t,s],b)) k
-
-
-
+                                                         templateMap =
+                                                           getUserTemplateMap
+                                                             (read tmpl :: [[String]])}{urls =
+                                                                                          mUrlState
+                                                                                            .
+                                                                                            fst .
+                                                                                              newtree
+                                                                                            $ g})
+        newtree g = makeLables g initialUrlState
+        tm = (postproctabmap (maketabmap theNewSizes Map.empty))
+        (trda, trst) = (alldata2 parsetree tm)
+        img = (map (\ g -> ((replace '\n' ' ' g))) (getImages trst))
+        theTables = reverse (tablist trst)
+        bdy = doUnicode trda
+        gals = getGalleryNumbers trst
+        tit = getTitle trst
+         
+        fun :: ByteString -> Double
+        fun x
+          = case reads (toString x) of
+                [(f, _)] -> f
+                _ -> (1000.0)
+        theSizes
+          = zip [1 ..] (map (\ x -> zip [1 ..] (map fun x)) someTables)
+        theNewSizes = concat (map sizeFun theSizes)
+        sizeFun (t, k) = map (\ (s, b) -> ([t, s], b)) k
+ 
 {-DHUN| the first parameter is the parse tree created by get parse of the document currently being processed. the second parameter is the URL under which the document was downloaded. the third parameter is the netloc describing the wiki this page belongs to. The fourth parameter is a mapping file defined by the user for the mapping of mediawiki templates to latex commands. the fifth parameter is a possible parse tree created by precious run the the should be added before the begging of the newly created parse tree. This function writes out all results to temporary files that will be further processed by compiler.py DHUN-}
  
 run ::
-    [Anything Char] ->
-      String -> String -> [[Anything Char]] -> IO ()
+    [Anything Char] -> String -> String -> [[Anything Char]] -> IO ()
 run x z tmpl cur
   = do y <- Prelude.readFile (tmppath ++ "imgnum")
        d <- Dir.getDirectoryContents tmppath
@@ -385,12 +401,9 @@ run x z tmpl cur
        (trda, trst) <- return
                          ((((alldata2 (jj ++ x) y
                                (postproctabmap (maketabmap lll Map.empty))))))
-       print (postproctabmap (maketabmap lll Map.empty))
        Tools.writeFile (tmppath ++ "images")
          (concat
-            (map (\ g -> ((replace '\n' ' ' g) ++ "\n"))
-               (getImages trst)))
-       print ((snd . newtree $ ((jj ++ x))))
+            (map (\ g -> ((replace '\n' ' ' g) ++ "\n")) (getImages trst)))
        Tools.writeFile (tmppath ++ "ttt.zzz")
          (show (reverse (tablist trst)))
        Tools.writeFile (tmppath ++ "test.tex") (doUnicode trda)
