@@ -2,6 +2,7 @@
 module MagicStrings where
 import Data.Char
 import Network.URI
+import Data.List.Split
 import qualified Data.Map as Map
  
 {-DHUN| Wikimedia project prefixes so 'de' from de.wikipedia.org DHUN-}
@@ -510,6 +511,18 @@ htmlchars
 getHtmlChar :: String -> String
 getHtmlChar x = Map.findWithDefault [] x (Map.fromList htmlchars)
  
+removePrintVersion :: [Char] -> [Char]
+removePrintVersion lem
+  = fun
+      ["/Print version", "/Complete Wikibook", "/All Chapters",
+       "/Print Version", "/print version", "/Printable version"]
+      lem
+  where fun (y : _) x
+          = case splitOn y x of
+                (z : _) -> z
+                _ -> []
+        fun [] x = x
+ 
 {-DHUN| Nearly all HTML tags DHUN-}
  
 goodtags1 :: [[Char]]
