@@ -41,7 +41,8 @@ data MyState = MyState{getImages :: [String], getJ :: Int,
                        templateMap :: Map String [String], urls :: Map String String,
                        urld :: WikiUrlData, getGalleryNumbers :: [Integer],
                        currentUrl :: String, fndict :: Map String [Anything Char],
-                       tablist :: [[String]], tabmap :: Map Int (Map Int Double), fontStack :: [FontStyle], font::Font}
+                       tablist :: [[String]], tabmap :: Map Int (Map Int Double),
+                       fontStack :: [FontStyle], font :: Font}
              deriving (Show, Eq)
  
 {-DHUN| Renderer is the State monad using MyState as mutable state DHUN-}
@@ -58,7 +59,10 @@ initialState
             getTitle = "", templateMap = Map.fromList [], urls = Map.empty,
             urld = BaseUrl (WikiBaseUrl ""), getGalleryNumbers = [],
             currentUrl = "", fndict = Map.empty, tablist = [],
-            tabmap = Map.empty, fontStack=[FontStyle {stylebase=Normal, bold=False, italic=False}], font=ComputerModernRoman}
+            tabmap = Map.empty,
+            fontStack =
+              [FontStyle{stylebase = Normal, bold = False, italic = False}],
+            font = ComputerModernRoman}
  
 {-DHUN| represents an URL to a wiki (not to a page thereof), which is not a sister project of wikipedia, so not wikibooks wikisource, etc. DHUN-}
  
