@@ -120,8 +120,7 @@ getUrlFromWikiLinkInfoesc i
                            (wikitype x) ++ ".org/wiki/" ++ (escapelink (urlEncode (page i)))
         BaseUrl (WikiBaseUrl x) -> "http://" ++
                                      x ++ "/wiki/" ++ (escapelink (urlEncode (page i)))
-
-
+ 
 {-DHUN| converts a WikiLinkInfo value pointing to a page on a wiki to the full url of that page as string. It is not is escaped in any way, so ready for use in a webbrowers DHUN-}
  
 getUrlFromWikiLinkInfo :: WikiLinkInfo -> String
@@ -129,11 +128,9 @@ getUrlFromWikiLinkInfo i
   = case (urldata i) of
         UrlInfo x -> "http://" ++
                        (language x) ++
-                         "." ++
-                           (wikitype x) ++ ".org/wiki/" ++ (urlEncode (page i))
+                         "." ++ (wikitype x) ++ ".org/wiki/" ++ (urlEncode (page i))
         BaseUrl (WikiBaseUrl x) -> "http://" ++
                                      x ++ "/wiki/" ++ (urlEncode (page i))
-
  
 {-DHUN| converts a WikiUrlData value pointing to a wiki and a string (like a part of a url) pointing to a page relative to that wiki and returns the full url of that page as string DHUN-}
  
